Learn R Programming

gpyramid (version 0.0.1)

calcCost: Function to calculate N_total by the algorithm proposed by Sevin et al. (2004)

Description

Function to calculate N_total by the algorithm proposed by Sevin et al. (2004)

Usage

calcCost(
  topolo,
  gene_df1_sel,
  gene_df2_sel,
  recom_mat,
  prob_total,
  last_cross = FALSE,
  last_selfing = FALSE
)

Value

`calCost` function returns the list of `n_plant_df`, `gene_df1_sel` and `gene_df2_sel`. `n_plant_df` contains the information about the number of progenies should be produced at each crossing (node in the tree).

Arguments

topolo

Crossing scheme described by topology of tree

gene_df1_sel

Parental set of crossing

gene_df2_sel

Parental set of crossing

recom_mat

Matrix of recombination rate among genes.

prob_total

Probability of success.

last_cross

Whether or not to conduct the last cross to a cultivar without target alleles.

last_selfing

Whether or not to conduct the last selfing.