Learn R Programming

gpyramid (version 0.0.1)

getFromAll: Function to get one crossing scheme from all the crossing schemes.

Description

Function to get one crossing scheme from all the crossing schemes.

Usage

getFromAll(gpyramid_all_obj, cross_id)

Value

getFromAll function returns a `getFromAll` object. This is a named list with the following components: * `topolo` (`phylo`): crossing scheme described as the phylo object, which is defined by ape package. * `last_cross` (`boolean`): Whether or not to conduct the last cross to a cultivar without target alleles. * `last_selfint` (`boolean`): Whether or not to conduct the last selfing. * `cost_onecrossing` (`list`): List of output information about one gene pyramiding scheme. The object has class `getFromAll` and can be summarized using `summary()`.

Arguments

gpyramid_all_obj

gpyramid_all object.

cross_id

cross_id in cost_all data frame.